Index: chan_h323.c
===================================================================
--- chan_h323.c	(revision 9323)
+++ chan_h323.c	(revision 10167)
@@ -961,12 +961,7 @@
 	if (pvt->rtp)
 		return 0;
 
-	if (ast_find_ourip(&our_addr, bindaddr)) {
-		ast_mutex_unlock(&pvt->lock);
-		ast_log(LOG_ERROR, "Unable to locate local IP address for RTP stream\n");
-		return -1;
-	}
-	pvt->rtp = ast_rtp_new_with_bindaddr(sched, io, 1, 0, our_addr);
+	pvt->rtp = ast_rtp_new_with_bindaddr(sched, io, 1, 0, bindaddr.sin_addr);
 	if (!pvt->rtp) {
 		ast_mutex_unlock(&pvt->lock);
 		ast_log(LOG_WARNING, "Unable to create RTP session: %s\n", strerror(errno));
@@ -1904,7 +1899,7 @@
   *
   * \return Returns the local RTP information
   */
-static struct rtp_info *external_rtp_create(unsigned call_reference, const char * token)
+static struct rtp_info *external_rtp_create(unsigned call_reference, const char * token, struct in_addr them)
 {
 	struct oh323_pvt *pvt;
 	struct sockaddr_in us;
@@ -1933,6 +1928,9 @@
 	ast_rtp_get_us(pvt->rtp, &us);
 	ast_mutex_unlock(&pvt->lock);
 
+	if (!us.sin_addr.s_addr) // 0.0.0.0
+	    ast_ouraddrfor(&them, &us.sin_addr);
+	
 	ast_copy_string(info->addr, ast_inet_ntoa(us.sin_addr), sizeof(info->addr));
 	info->port = ntohs(us.sin_port);
 	if (h323debug)
Index: ast_h323.cxx
===================================================================
--- h323/ast_h323.cxx	(revision 9319)
+++ h323/ast_h323.cxx	(working copy)
@@ -2136,8 +2140,14 @@
 {
 	struct rtp_info *info;
 
+	PIPSocket::Address addr;
+	WORD port;	
+	connection.GetSignallingChannel()->GetRemoteAddress().GetIpAndPort(addr, port); 
+	
 	/* Determine the Local (A side) IP Address and port */
-	info = on_external_rtp_create(connection.GetCallReference(), (const char *)connection.GetCallToken());
+	info = on_external_rtp_create(connection.GetCallReference(), 
+		    (const char *)connection.GetCallToken(), 
+		    static_cast<in_addr>(addr));
 	if (!info) {
 		cout << "\tERROR: on_external_rtp_create failure" << endl;
 		return;
Index: chan_h323.h
===================================================================
--- h323/chan_h323.h	(revision 9319)
+++ h323/chan_h323.h	(working copy)
@@ -139,7 +141,7 @@
 
 /* This is a callback prototype function, called to collect
    the external RTP port from Asterisk. */
-typedef rtp_info_t *(*on_rtp_cb)(unsigned, const char *);
+typedef rtp_info_t *(*on_rtp_cb)(unsigned, const char *, struct in_addr);
 extern on_rtp_cb on_external_rtp_create;
 
 /* This is a callback prototype function, called to send
